<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfStatisticsTrackerSplit.php 1239 2005-01-17 17:39:11Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once maintenancePath . '/libraries/max/Dal/StatisticsTrackerSplit.php';

/**
 * A class for testing the Dal_Statistics_AdServerSplit class.
 */
class Dal_TestOfStatisticsTrackerSplit extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Dal_TestOfStatisticsTrackerSplit()
    {
        $this->UnitTestCase();
    }
    
    /**
     * Tests that the singleton() method only ever returns one class instance.
     */
    function testSingleton()
    {
        debug('Running test', PEAR_LOG_INFO);
        $first =& Dal_Statistics_Tracker_Split::singleton();
        $second =& Dal_Statistics_Tracker_Split::singleton();
        $this->assertIdentical($first, $second);
    }
    
    /**
     * Tests the getMaintenanceStatisticsLastRunInfo() method.
     */
    function testGetMaintenanceStatisticsLastRunInfo()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['table']['split'] = true;
        $conf['maintenance']['operation_interval'] = 60;
        $dsa =& Dal_Statistics_Tracker_Split::singleton();
        // Create the required tables
        $now = new Date();
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('log_maintenance_statistics');
        // Test with no data
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertNull($date);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertNull($date);
        // Insert ad impressions
        $now->setHour(18);
        $now->setMinute(22);
        $now->setSecond(10);
        $query = "
            INSERT INTO
                max_data_raw_tracker_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $dsa->execute($query, $result);
        $now->setHour(12);
        $now->setMinute(34);
        $now->setSecond(56);
        $query = "
            INSERT INTO
                max_data_raw_tracker_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $dsa->execute($query, $result);
        $now->setHour(18);
        $now->setMinute(22);
        $now->setSecond(11);
        $query = "
            INSERT INTO
                max_data_raw_tracker_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $dsa->execute($query, $result);
        $now->setHour(11);
        $now->setMinute(59);
        $now->setSecond(59);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, $now);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, $now);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsTrackerSplit.php';
        // Insert an hourly (only) update
        $dsa->execute(TOT_SPLIT_LMS_HOUR, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, $now);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert an operation interval (only) update
        $dsa->execute(TOT_SPLIT_LMS_OI, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, new Date('2004-06-06 10:16:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert a dual interval update
        $dsa->execute(TOT_SPLIT_LMS_DUAL, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['log_maintenance_statistics']);
    }

    /**
     * Tests the deleteOldData() method.
     */
    function testDeleteOldData()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['table']['split'] = true;
        $conf['maintenance']['compact_stats_grace'] = 0;
        $dsa =& Dal_Statistics_Tracker_Split::singleton();
        // Create the required tables
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_tracker_click', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_tracker_click', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsTrackerSplit.php';
        // Insert the test data
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_CLICKS_ONE, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_CLICKS_TWO, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS_ONE, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS_TWO, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_REQUESTS_ONE, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_REQUESTS_TWO, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_click']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_impression']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_impression']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_variable_value']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_variable_value']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Drop the tables
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_variable_value'] . '_' . $now->format('%Y%m%d'));
        // Set a compact_stats_grace window
        $conf['maintenance']['compact_stats_grace'] = 3600;
        // Create the required tables
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_tracker_click', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_tracker_click', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        // Insert the test data
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_CLICKS_ONE, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_CLICKS_TWO, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS_ONE, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS_TWO, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_REQUESTS_ONE, $result);
        $dsa->execute(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_REQUESTS_TWO, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_click']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_impression']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_impression']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_variable_value']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_variable_value']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Drop the tables
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_variable_value'] . '_' . $now->format('%Y%m%d'));
    }
    
}

?>
